### 0.1.6
- alternative logout scheme has a timed redirect to the login page after 5 seconds 

### 0.1.5
- add an alternative logout scheme for Shibboleth.sso/Logout procedures
  which don't support http redirects

### 0.1.4
- initial release